From b15920d5a66d379c9fd9cb15fcc48f0f078e7c77 Mon Sep 17 00:00:00 2001
From: zhubaomin <zhubaomin>
Date: 星期一, 28 十月 2024 14:52:53 +0800
Subject: [PATCH] Merge branch 'master' of http://8.140.179.55:20000/r/pipIrr-SV

---
 pipIrr-platform/pipIrr-web/pipIrr-web-sell/src/main/java/com/dy/pipIrrSell/recharge/RechargeCtrl.java |   59 ++++++++++++++++++++++++++++++++++-------------------------
 1 files changed, 34 insertions(+), 25 deletions(-)

diff --git a/pipIrr-platform/pipIrr-web/pipIrr-web-sell/src/main/java/com/dy/pipIrrSell/recharge/RechargeCtrl.java b/pipIrr-platform/pipIrr-web/pipIrr-web-sell/src/main/java/com/dy/pipIrrSell/recharge/RechargeCtrl.java
index b795839..f79e599 100644
--- a/pipIrr-platform/pipIrr-web/pipIrr-web-sell/src/main/java/com/dy/pipIrrSell/recharge/RechargeCtrl.java
+++ b/pipIrr-platform/pipIrr-web/pipIrr-web-sell/src/main/java/com/dy/pipIrrSell/recharge/RechargeCtrl.java
@@ -11,8 +11,8 @@
 import com.dy.pipIrrGlobal.voSe.VoRecharge;
 import com.dy.pipIrrSell.clientCard.ClientCardSv;
 import com.dy.pipIrrSell.clientCard.LastOperateENUM;
+import com.dy.pipIrrSell.result.SellResultCode;
 import io.swagger.v3.oas.annotations.Operation;
-import io.swagger.v3.oas.annotations.Parameter;
 import io.swagger.v3.oas.annotations.media.Content;
 import io.swagger.v3.oas.annotations.media.Schema;
 import io.swagger.v3.oas.annotations.responses.ApiResponse;
@@ -26,10 +26,7 @@
 import org.springframework.validation.BindingResult;
 import org.springframework.web.bind.annotation.*;
 
-import java.util.Date;
-import java.util.List;
-import java.util.Objects;
-import java.util.Optional;
+import java.util.*;
 
 @Slf4j
 @Tag(name = "鍏呭�肩鐞�", description = "鍏呭�兼搷浣�")
@@ -49,9 +46,10 @@
                             schema = @Schema(implementation = VoRecharge.class))}
             )
     })
-    @GetMapping(path = "/getRecharges", consumes = MediaType.APPLICATION_JSON_VALUE)
-    @SsoAop("-1")
-    public BaseResponse<QueryResultVo<List<VoRecharge>>> get(@RequestBody @Parameter(description = "鏌ヨform琛ㄥ崟json鏁版嵁", required = true) QueryVo vo){
+    //@GetMapping(path = "/getRecharges", consumes = MediaType.APPLICATION_JSON_VALUE)
+    @GetMapping(path = "/getRecharges")
+    @SsoAop()
+    public BaseResponse<QueryResultVo<List<VoRecharge>>> get(QueryVo vo){
         try {
             QueryResultVo<List<VoRecharge>> res = rechargeSv.getRecharges(vo);
             return BaseResponseUtils.buildSuccess(res);
@@ -72,8 +70,8 @@
     })
     @PostMapping(path = "add", consumes = MediaType.APPLICATION_JSON_VALUE)
     @Transactional(rollbackFor = Exception.class)
-    @SsoAop("-1")//@SsoAop(power = "-1")
-    public BaseResponse<Boolean> add(@RequestBody @Parameter(description = "form琛ㄥ崟json鏁版嵁", required = true) @Valid DtoRecharge po, @Parameter(hidden = true) BindingResult bindingResult){
+    @SsoAop()
+    public BaseResponse<Boolean> add(@RequestBody @Valid DtoRecharge po, BindingResult bindingResult){
         if(bindingResult != null && bindingResult.hasErrors()){
             return BaseResponseUtils.buildFail(Objects.requireNonNull(bindingResult.getFieldError()).getDefaultMessage());
         }
@@ -87,9 +85,9 @@
      */
     public BaseResponse<Boolean> addRecharge(DtoRecharge po){
         /**
          * cardId           姘村崱缂栧彿锛堥潪浼犲叆鍙傛暟锛岀敱cardAddr鍙嶆煡锛�
          * cardAddr         姘村崱鍦板潃
          * clientId         鍐滄埛缂栧彿
          * money            鍗$墖浣欓
          * amount           鍏呭�奸噾棰�
          * gift             璧犻�侀噾棰�
@@ -101,12 +99,13 @@
          * rechargeTime     鍏呭�兼椂闂�
          */
         Long cardId = 0L;
-        String cardAddr = po.getCardAddr();
-        Long clientId = po.getClientId();
+        Long cardNum = po.getCardNum();
+        String clientNum = "";
+        //Long clientId = po.getClientId();
+        Long clientId = 0L;
         Float money = po.getMoney();
         Float amount = po.getAmount();
         Float gift = po.getGift();
-        //Float afterRecharge = po.getAfterRecharge();
         Float afterRecharge = money + amount + gift;
         Long paymentId = po.getPaymentId();
         Float price = po.getPrice();
@@ -115,12 +114,15 @@
         Date rechargeTime = new Date();
 
         /**
-         * 渚濇嵁姘村崱鍦板潃鑾峰彇姘村崱缂栧彿锛堜富閿級
+         * 渚濇嵁姘村崱缂栧彿鑾峰彇姘村崱琛ㄤ富閿強鍐滄埛缂栧彿
          */
-        cardId = Optional.ofNullable(clientCardSv.getCardIdByAddr(cardAddr)).orElse(0L);
-        if(cardId == 0) {
-            return BaseResponseUtils.buildFail("鍗″彿閿欒锛岃鍗′笉瀛樺湪");
+        Map map = Optional.ofNullable(clientCardSv.getCardIdAndClientNum(cardNum)).orElse(new HashMap());
+        if(map == null || map.size() <= 0) {
+            return BaseResponseUtils.buildFail(SellResultCode.CARD_NUMBER_MISTAKE.getMessage());
         }
+        cardId = Long.parseLong(map.get("cardId").toString());
+        clientNum = map.get("clientNum").toString();
+        clientId = Long.parseLong(map.get("clientId").toString());
 
         /**
          * 淇敼鍐滄埛鍗′俊鎭細
@@ -129,11 +131,12 @@
          */
         SeClientCard seClientCard = new SeClientCard();
         seClientCard.setId(cardId);
+        seClientCard.setMoney(afterRecharge);
         seClientCard.setRechargedt(rechargeTime);
         seClientCard.setLastoper(LastOperateENUM.RECHARGE.getCode ());
         Integer rec_updateClientCard = Optional.ofNullable(clientCardSv.UpdateClientCard(seClientCard)).orElse(0);
         if(rec_updateClientCard == 0) {
-            return BaseResponseUtils.buildFail("鍏呭�煎け璐�-鍐滄埛鍗′慨鏀瑰紓甯�");
+            return BaseResponseUtils.buildFail(SellResultCode.RECHARGE_FAIL_WRITE_CLIENT_CARD_ERROR.getMessage());
         }
 
         /**
@@ -144,6 +147,9 @@
          * 娣诲姞鍏呭�艰褰�
          */
         SeRecharge seRecharge = new SeRecharge();
+        //seRecharge.setCardnum(cardNum);
+        //seRecharge.setClientnum(clientNum);
+
         seRecharge.setCardid(cardId);
         seRecharge.setClientid(clientId);
         seRecharge.setMoney(money);
@@ -157,13 +163,15 @@
         seRecharge.setOperatedt(rechargeTime);
         Long rec = Optional.ofNullable(rechargeSv.add(seRecharge)).orElse(0L);
         if(rec == 0) {
-            return BaseResponseUtils.buildFail("鍏呭�煎け璐�-鍏呭�艰褰曞啓鍏ュ紓甯�");
+            return BaseResponseUtils.buildFail(SellResultCode.REPLACE_FAIL_WRITE_RECHARGE_ERROR.getMessage());
         }
 
         /**
          * 娣诲姞琛ュ崱鍘嗗彶璁板綍
          */
         SeRechargeHistory seRechargeHistory = new SeRechargeHistory();
+        //seRechargeHistory.setCardnum(cardNum);
+        //seRechargeHistory.setClientnum(clientNum);
         seRechargeHistory.setCardid(cardId);
         seRechargeHistory.setClientid(clientId);
         seRechargeHistory.setMoney(money);
@@ -178,9 +186,10 @@
 
         Long rec_history = Optional.ofNullable(rechargeSv.addHistory(seRechargeHistory)).orElse(0L);
         if(rec_history == 0) {
-            return BaseResponseUtils.buildFail("鍏呭�煎け璐�-鍏呭�煎巻鍙茶褰曞啓鍏ュ紓甯�");
+            return BaseResponseUtils.buildFail(SellResultCode.RECHARGE_FAIL_WRITE_RECHARGE_HISTORY_ERROR.getMessage());
         }
-
-        return BaseResponseUtils.buildSuccess(true) ;
+        Map returnMap = new HashMap();
+        returnMap.put("orderNumber",rec+"");//杩斿洖鍏呭�糏D
+        return BaseResponseUtils.buildSuccess(returnMap) ;
     }
 }
@@ -87,9 +85,9 @@
     public BaseResponse<Boolean> addRecharge(DtoRecharge po){
         /**
-         * cardId           姘村崱缂栧彿锛堥潪浼犲叆鍙傛暟锛岀敱cardAddr鍙嶆煡锛�
-         * cardAddr         姘村崱鍦板潃
-         * clientId         鍐滄埛缂栧彿
+         * cardId           姘村崱缂栧彿锛堟彃鍏ヨ褰曞悗鐢熸垚锛�
+         * cardAddr         姘村崱鍦板潃锛堜粎浠呭啓鍏ワ紝鏃犱笟鍔★級
+         * clientNum        鍐滄埛缂栧彿锛堥潪浼犲叆鍙傛暟锛岀敱cardNum鍙嶆煡锛屾坊鍔犲厖鍊间娇鐢級
          * money            鍗$墖浣欓
          * amount           鍏呭�奸噾棰�

--
Gitblit v1.8.0